package com.huimv.production.datasource.utils;


import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONObject;
import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.interfaces.DecodedJWT;
import com.huimv.common.result.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @Project : huimv.shiwan
 * @Package : com.example.demo.util
 * @Description : TODO
 * @Author : yuxuexuan
 * @Create : 2021/2/26 0026 9:06
 **/
@Component
@Slf4j
public class TokenUtil {
    // 过期时间设为30分钟
    private static final long EXPIRE_TIME = 1 * 2 * 60 * 1000;  //有效时长
    private static final String TOKEN_SECRET = "qinglian";       // 秘钥

    /**
     * 签名 生成
     *
     * @parm userName
     */
    public static String sign(String userName) {
        String token = null;
        try {
            Date expiresAt = new Date(System.currentTimeMillis() + EXPIRE_TIME);
            token = JWT.create()
                    .withIssuer("auth0")
                    .withClaim("userName", userName)
                    .withExpiresAt(expiresAt)
                    //使用HMAC256算法加密
                    .sign(Algorithm.HMAC256(TOKEN_SECRET));
        } catch (Exception e) {
            e.printStackTrace();
        }
        return token;
    }

    /**
     * 签名验证
     *
     * @param token
     */
    public static boolean verify(String token) {
        try {
            JWTVerifier verifier = JWT.require(Algorithm.HMAC256(TOKEN_SECRET))
                    .withIssuer("auth0").build();
            DecodedJWT jwt = verifier.verify(token);
//            log.info("TOKEN过期时间：" + DateUtil.format(jwt.getExpiresAt(), "yyyy-MM-dd HH:mm:ss"));
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    /**
     * @Method      : verifyToken
     * @Description : 签名验证
     * @Params      : [token]
     * @Return      : com.alibaba.fastjson.JSONObject
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 18:53
     */
    public Result verifyToken(String token) {
        if(StringUtils.isBlank(token)){
            return new Result(10001,"token不能为空.",false);
        }
        try {
            JWTVerifier verifier = JWT.require(Algorithm.HMAC256(TOKEN_SECRET))
                    .withIssuer("auth0").build();
            DecodedJWT jwt = verifier.verify(token);
            log.info("TOKEN过期时间：" + DateUtil.format(jwt.getExpiresAt(), "yyyy-MM-dd HH:mm:ss"));
            return new Result(10000,"验证token成功.",true);
        } catch (Exception e) {
            return new Result(10004,"验证token出错："+e.getMessage(),false);
        }
    }
}
